#include "playlistaspectlistviewmodel.h"
#include "debug.h"

PlayListAspectListViewModel::PlayListAspectListViewModel(PlayListAspectListViewRenderer *aspect)
    :	QAbstractListModel(aspect),
        aspect_(aspect)
{
}

int PlayListAspectListViewModel::rowCount(const QModelIndex &parent) const
{
    return aspect_->itemList()->count();
}

int PlayListAspectListViewModel::columnCount(const QModelIndex &parent) const
{
    return 6;
}

QVariant PlayListAspectListViewModel::data(const QModelIndex &index, int role) const
{
    if (!index.isValid())
        return QVariant();

    PlayListItemList *itemList = aspect_->itemList();

    if (index.row() >= itemList->size())
        return QVariant();

    if (role == Qt::DisplayRole)
    {
        QString t;
        Media *currentMedia = itemList->at(index.row())->media();

        switch (index.column())
        {
        case 0:
            t = QString::null;
            break;
        case 1:
            t = currentMedia->trackNo() + "  ";
            break;
        case 2:
            t = currentMedia->title();
            break;
        case 3:
            t = currentMedia->artist();
            break;
        case 4:
            t = currentMedia->album();
            break;
        case 5:
            t = currentMedia->playTime();
            break;
        }

        return t;
    }
    else
        return QVariant();
}

QVariant PlayListAspectListViewModel::headerData(int section, Qt::Orientation orientation, int role) const
{
    if (role != Qt::DisplayRole)
        return QVariant();

    if (orientation == Qt::Horizontal)
    {
        QString t;
        switch (section)
        {
        case 0:
            t = QString::null;
            break;
        case 1:
            t = "No.";
            break;
        case 2:
            t = "Title";
            break;
        case 3:
            t = "Artist";
            break;
        case 4:
            t = "Album";
            break;
        case 5:
            t = "Length";
            break;
        }

        return t;
    }
    else
        return QVariant();
}

void PlayListAspectListViewModel::sort(int column, Qt::SortOrder order)
{
    DGUARDMETHOD;
    if (column != aspect_->sortedColumn())
        aspect_->setSortParams(column, order == Qt::AscendingOrder);
    else
        aspect_->setSortParams(aspect_->sortedColumn(), !aspect_->isSortAscending());

    DPRINTF("Header section %d clicked. Preparing playlist item index...", column);
}

void PlayListAspectListViewModel::rereadData()
{
    emit layoutChanged();
}
